@@ -1,12 +1,10 @@
 import datetime
 import logging
-import uuid
 from enum import Enum
 
 from kinto.core.events import ACTIONS
 from kinto.core.storage.exceptions import RecordNotFoundError
 from pyramid.security import Everyone
-from pyramid.settings import aslist
 
 from kinto_signer.serializer import canonical_json
 from kinto_signer.utils import STATUS, ensure_resource_exists, notify_resource_event, records_diff
@@ -133,13 +131,10 @@ class LocalUpdater(object):
         if next_source_status is not None:
             self.update_source_status(next_source_status, request, previous_source_status)
 
-        self.invalidate_cloudfront_cache(request, timestamp)
-
         return changes_count
 
     def refresh_signature(self, request, next_source_status=None):
-        """Refresh the signature without moving records.
-        """
+        """Refresh the signature without moving records."""
         records, timestamp = self.get_destination_records(empty_none=False)
         serialized_records = canonical_json(records, timestamp)
         logger.debug(f"{self.source_collection_uri}:\t'{serialized_records}'")
@@ -236,8 +231,7 @@ class LocalUpdater(object):
         return changed_count
 
     def create_destination(self, request):
-        """Create the destination bucket/collection if they don't already exist.
-        """
+        """Create the destination bucket/collection if they don't already exist."""
         # With the current implementation, the destination is not writable by
         # anyone and readable by everyone.
         # https://github.com/Kinto/kinto-signer/issues/55
@@ -316,7 +310,10 @@ class LocalUpdater(object):
             deleted = record.get("deleted", False)
             if deleted:
                 try:
-                    pushed = self.storage.delete(object_id=record[FIELD_ID], **storage_kwargs,)
+                    pushed = self.storage.delete(
+                        object_id=record[FIELD_ID],
+                        **storage_kwargs,
+                    )
                     action = ACTIONS.DELETE
                 except RecordNotFoundError:
                     # If the record doesn't exists in the destination
@@ -454,31 +451,3 @@ class LocalUpdater(object):
             action=ACTIONS.UPDATE,
             old=collection_record,
         )
-
-    def invalidate_cloudfront_cache(self, request, timestamp):
-        settings = request.registry.settings
-        distribution_id = settings.get("signer.distribution_id")
-
-        if not distribution_id:
-            return
-
-        paths = aslist(settings.get("signer.invalidation_paths", "/v1/*"))
-
-        # Paths can have placeholders with destination bucket/collection
-        bid = self.destination["bucket"]
-        cid = self.destination["collection"]
-        paths = [p.format(bucket_id=bid, collection_id=cid) for p in paths]
-
-        try:
-            # Create a boto client
-            client = boto3.client("cloudfront")
-            client.create_invalidation(
-                DistributionId=distribution_id,
-                InvalidationBatch={
-                    "Paths": {"Quantity": len(paths), "Items": paths},
-                    "CallerReference": f"{timestamp}-{uuid.uuid4()}",
-                },
-            )
-            logger.info("Invalidated CloudFront cache at %s" % ", ".join(paths))
-        except Exception:
-            logger.exception("Cache invalidation request failed.")
