@@ -1047,10 +1047,10 @@ class CollectionDelete(SignoffWebTest, unittest.TestCase):
         self.app.delete(self.destination_bucket + "/collections/extra", headers=self.headers)
 
 
-class NoReviewNoPreviewTest(SignoffWebTest, unittest.TestCase):
+class NoReviewTest(SignoffWebTest, unittest.TestCase):
     """
-    If review is disabled for a collection, we don't create the preview collection
-    nor copy the records there.
+    If preview collection is set in config, we create it
+    and copy the records there, even if review is disabled.
     """
 
     source_bucket = "/buckets/dev"
@@ -1064,20 +1064,21 @@ class NoReviewNoPreviewTest(SignoffWebTest, unittest.TestCase):
     def get_app_settings(cls, extras=None):
         settings = super().get_app_settings(extras)
 
-        settings["signer.to_review_enabled"] = "true"
-        settings["signer.group_check_enabled"] = "true"
-
+        # preview collection exists.
         settings["kinto.signer.resources"] = " -> ".join(
             (cls.source_bucket, cls.preview_bucket, cls.destination_bucket)
         )
-
+        # dev/onecrl has review enabled.
+        settings["signer.to_review_enabled"] = "true"
+        settings["signer.group_check_enabled"] = "true"
+        # dev/normandy has review disabled.
         settings["signer.dev.normandy.to_review_enabled"] = "false"
         settings["signer.dev.normandy.group_check_enabled"] = "false"
 
         return settings
 
     def setUp(self):
-        super(NoReviewNoPreviewTest, self).setUp()
+        super().setUp()
         # Make the preview bucket readable (to obtain explicit 404 when collections
         # don't exist instead of ambiguous 403)
         self.app.put_json(
@@ -1085,19 +1086,44 @@ class NoReviewNoPreviewTest(SignoffWebTest, unittest.TestCase):
             {"permissions": {"read": ["system.Everyone"]}},
             headers=self.headers,
         )
+        self.app.put(self.source_bucket + "/collections/onecrl", headers=self.headers)
+        self.app.put(self.source_collection, headers=self.headers)
 
-    def test_the_preview_collection_is_not_created(self):
-        self.app.put_json(
-            self.source_bucket + "/collections/onecrl", status=201, headers=self.headers
+    def test_the_preview_collection_is_created_when_review_enabled(self):
+        self.app.get(self.preview_bucket + "/collections/onecrl", headers=self.headers)
+
+    def test_the_preview_collection_is_created_when_review_disabled(self):
+        self.app.get(self.preview_collection, headers=self.headers)
+
+    def test_the_preview_collection_is_updated_when_review_enabled(self):
+        before = len(
+            self.app.get(
+                self.preview_bucket + "/collections/onecrl/records", headers=self.headers
+            ).json["data"]
+        )
+        self.app.post_json(
+            self.source_bucket + "/collections/onecrl/records",
+            {"data": {"title": "Hallo"}},
+            headers=self.headers,
         )
-        self.app.put_json(self.source_collection, headers=self.headers)
 
-        self.app.get(self.preview_bucket + "/collections/onecrl", status=200, headers=self.headers)
-        self.app.get(self.preview_collection, status=404, headers=self.headers)
+        self.app.patch_json(
+            self.source_bucket + "/collections/onecrl",
+            {"data": {"status": "to-review"}},
+            headers=self.headers,
+        )
 
-    def test_the_preview_collection_is_not_updated(self):
-        r = self.app.get(self.destination_collection + "/records", headers=self.headers)
-        before = len(r.json["data"])
+        after = len(
+            self.app.get(
+                self.preview_bucket + "/collections/onecrl/records", headers=self.headers
+            ).json["data"]
+        )
+        assert after > before, "Preview was not updated when review enabled"
+
+    def test_the_preview_collection_is_updated_when_review_disabled(self):
+        before = len(
+            self.app.get(self.preview_collection + "/records", headers=self.headers).json["data"]
+        )
         self.app.post_json(
             self.source_collection + "/records", {"data": {"title": "Hallo"}}, headers=self.headers
         )
@@ -1106,11 +1132,97 @@ class NoReviewNoPreviewTest(SignoffWebTest, unittest.TestCase):
             self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
         )
 
-        # The preview still does not exist :)
-        self.app.get(self.preview_collection, status=404, headers=self.headers)
-        # Prod was updated.
-        r = self.app.get(self.destination_collection + "/records", headers=self.headers)
-        assert len(r.json["data"]) > before
+        after = len(
+            self.app.get(self.preview_collection + "/records", headers=self.headers).json["data"]
+        )
+        assert after > before, "Preview was not updated when review disabled"
+
+
+class NoPreviewTest(SignoffWebTest, unittest.TestCase):
+    """
+    If preview collection is not set in config, we don't create it
+    even if review is enabled.
+    """
+
+    source_bucket = "/buckets/dev"
+    source_collection = "/buckets/dev/collections/normandy"
+    preview_bucket = "/buckets/preview"
+    destination_bucket = "/buckets/prod"
+    destination_collection = "/buckets/prod/collections/normandy"
+
+    @classmethod
+    def get_app_settings(cls, extras=None):
+        settings = super().get_app_settings(extras)
+
+        # No preview collection.
+        settings["kinto.signer.resources"] = " -> ".join(
+            (cls.source_bucket, cls.destination_bucket)
+        )
+        # dev/onecrl has review enabled.
+        settings["signer.to_review_enabled"] = "true"
+        settings["signer.group_check_enabled"] = "true"
+        # dev/normandy has review disabled.
+        settings["signer.dev.normandy.to_review_enabled"] = "false"
+        settings["signer.dev.normandy.group_check_enabled"] = "false"
+
+        return settings
+
+    def setUp(self):
+        super().setUp()
+        self.app.put(self.preview_bucket, headers=self.headers)
+        self.app.put(self.source_bucket + "/collections/onecrl", headers=self.headers)
+        self.app.put_json(self.source_collection, headers=self.headers)
+
+    def test_the_preview_collection_is_not_created_when_review_enabled(self):
+        self.app.get(self.preview_bucket + "/collections/onecrl", status=404, headers=self.headers)
+
+    def test_the_preview_collection_is_not_created_when_review_disabled(self):
+        self.app.get(
+            self.preview_bucket + "/collections/normandy", status=404, headers=self.headers
+        )
+
+    def test_the_preview_collection_is_not_updated_when_review_enabled(self):
+        self.app.post_json(
+            self.source_bucket + "/collections/onecrl/records",
+            {"data": {"title": "Hallo"}},
+            headers=self.headers,
+        )
+
+        self.app.patch_json(
+            self.source_bucket + "/collections/onecrl",
+            {"data": {"status": "to-review"}},
+            headers=self.headers,
+        )
+
+        # The preview still doesn't exist
+        self.app.get(self.preview_bucket + "/collections/onecrl", status=404, headers=self.headers)
+        # Destination will updated on review approval.
+
+    def test_the_preview_collection_is_not_updated_when_review_disabled(self):
+        before = len(
+            self.app.get(self.destination_collection + "/records", headers=self.headers).json[
+                "data"
+            ]
+        )
+        self.app.post_json(
+            self.source_collection + "/records", {"data": {"title": "Hallo"}}, headers=self.headers
+        )
+
+        self.app.patch_json(
+            self.source_collection, {"data": {"status": "to-sign"}}, headers=self.headers
+        )
+
+        # The preview still doesn't exist
+        self.app.get(
+            self.preview_bucket + "/collections/normandy", status=404, headers=self.headers
+        )
+        # And destination was updated.
+        after = len(
+            self.app.get(self.destination_collection + "/records", headers=self.headers).json[
+                "data"
+            ]
+        )
+        assert after > before, "Destination was not updated when review enabled"
 
 
 class PerBucketTest(SignoffWebTest, unittest.TestCase):
